[![Gitter chat](http://img.shields.io/badge/gitter-join%20chat%20%E2%86%92-brightgreen.svg)](https://gitter.im/opentracing/public)

# Basictracer Python

A python version of the "BasicTracer" reference implementation for OpenTracing.
